# -*- coding:utf-8 -*-
import numpy as np
from MyModules.mk_plot import MakePlot as mk_plot

# ===========================================================================
# 正規分布の密度関数
# ===========================================================================
class normal_distribution():
    ''' 一次元と二次元の正規分布の確率密度関数 '''
    def __init__(self, mu, sigma, rho=np.nan):
        ''' コンストラクター '''
        self.mu, self.sigma, self.rho = mu, sigma, rho
        
    def dim_1(self, x):
        return 1/np.sqrt(2*np.pi*self.sigma**2)*\
            np.exp(-(x-self.mu)**2/(2*self.sigma**2))

    def dim_2(self, x, y):
        sx, sy   = self.sigma[0], self.sigma[1]
        mux, muy = self.mu[0], self.mu[1]
        r = self.rho
        return 1.0/(2*np.pi*np.sqrt(1-r))*np.exp(-1.0/(2*(1-r**2))*(
            ((x-mux)/sx)**2 - 2*r*((x-mux)/sx)*((y-muy)/sy) + ((y-muy)/sy)**2
        ))

# ===========================================================================
# メインルーチン
# ===========================================================================
if __name__ == "__main__":
    ''' メインルーチン '''

    # ----- プロットデータの作成 (一次元正規分布) -----
    x_range, mu, sigma, N = [-10, 10], 1.2, 2.5, 256
    y_range = [0, 0.18]

    x = np.linspace(*x_range, N, endpoint=True)
    f = normal_distribution(mu, sigma)
    y = f.dim_1(x)

    # ----- プロットの作成 -----
    plot = mk_plot()
    plot_parameters = {'x':{'range':x_range, 'title':r'$x$', 'tick_step':2},
                       'y':{'range':y_range, 'title':r'$f(x)$', 'tick_step':0.02}}
    plot.line(x, y, plot_parameters, 'normal_dist_1D')

